.. rst-class:: hide-header

Flask-WTF
=========

.. image:: _static/flask-wtf.png
    :alt: Flask-WTF
    :align: center

Simple integration of `Flask`_ and `WTForms`_, including CSRF, file upload,
and reCAPTCHA.

.. _Flask: https://www.palletsprojects.com/p/flask
.. _WTForms: https://wtforms.readthedocs.io/

Features
--------

* Integration with WTForms.
* Secure Form with CSRF token.
* Global CSRF protection.
* reCAPTCHA support.
* File upload that works with Flask-Uploads.
* Internationalization using Flask-Babel.

User's Guide
------------

This part of the documentation, which is mostly prose, begins with some
background information about Flask-WTF, then focuses on step-by-step
instructions for getting the most out of Flask-WTF.

.. toctree::
   :maxdepth: 2

   install
   quickstart
   form
   csrf
   config

API Documentation
-----------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

Additional Notes
----------------

Legal information and changelog are here.

.. toctree::
   :maxdepth: 2

   license
   changes
   contributing
